@@ -80,6 +80,10 @@ impl<V: X3dhVault> std::fmt::Debug for Responder<V> {
 }
 
 impl<V: X3dhVault> KeyExchanger for Responder<V> {
+    fn name(&self) -> String {
+        "X3DH".to_string()
+    }
+
     fn generate_request(&mut self, _payload: &[u8]) -> Result<Vec<u8>> {
         match self.state {
             ResponderState::SendBundle => {
